==> jc-1.4.0.tar.gz: polyglot/types/reflect/Constant.h <==
// class polyglot.types.reflect.Constant

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 209b8df6d16abcfb polyglot_types_reflect_Constant

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_reflect_Constant_H_
#define _JC_polyglot_types_reflect_Constant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_Constant$sub_refs	_jc_polyglot_types_reflect_Constant$sub_refs;
typedef struct _jc_polyglot_types_reflect_Constant$sub_nonrefs	_jc_polyglot_types_reflect_Constant$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_Constant$refs	_jc_polyglot_types_reflect_Constant$refs;
typedef struct _jc_polyglot_types_reflect_Constant$nonrefs	_jc_polyglot_types_reflect_Constant$nonrefs;
typedef struct _jc_polyglot_types_reflect_Constant$object	_jc_polyglot_types_reflect_Constant$object;

typedef struct _jc_polyglot_types_reflect_Constant$fields_struct	_jc_polyglot_types_reflect_Constant$fields_struct;
typedef const struct _jc_polyglot_types_reflect_Constant$vmethods	_jc_polyglot_types_reflect_Constant$vmethods;
typedef const struct _jc_polyglot_types_reflect_Constant$vtable	_jc_polyglot_types_reflect_Constant$vtable;
typedef const struct _jc_polyglot_types_reflect_Constant$vtype	_jc_polyglot_types_reflect_Constant$vtype;

// Class fields structure
struct _jc_polyglot_types_reflect_Constant$fields_struct {
	jbyte	CLASS;
	jbyte	DOUBLE;
	jbyte	FIELD__5fREF;
	jbyte	FLOAT;
	jbyte	INTEGER;
	jbyte	INTERFACE__5fMETHOD__5fREF;
	jbyte	LONG;
	jbyte	METHOD__5fREF;
	jbyte	NAME__5fAND__5fTYPE;
	jbyte	STRING;
	jbyte	UTF8;
};
extern _jc_polyglot_types_reflect_Constant$fields_struct _jc_polyglot_types_reflect_Constant$class_fields;

// Constructors
extern void _jc_polyglot_types_reflect_Constant$method$_init$964b4a8e45252143(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *, jint, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_polyglot_types_reflect_Constant$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_polyglot_types_reflect_Constant$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *);
extern jint _jc_polyglot_types_reflect_Constant$method$tag$c2c248fecb47553d(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *);
extern struct _jc_java_lang_Object$object *_jc_polyglot_types_reflect_Constant$method$value$b004c9f911e85e83(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_reflect_Constant$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_types_reflect_Constant$method_info$hashCode$53152098849316df;
extern _jc_method _jc_polyglot_types_reflect_Constant$method_info$tag$c2c248fecb47553d;
extern _jc_method _jc_polyglot_types_reflect_Constant$method_info$value$b004c9f911e85e83;

// Virtual methods structure
struct _jc_polyglot_types_reflect_Constant$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *);
	jint	(*tag$c2c248fecb47553d)(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *);
	struct _jc_java_lang_Object$object	*(*value$b004c9f911e85e83)(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *);
};

// Vtable
struct _jc_polyglot_types_reflect_Constant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_Constant$vmethods	polyglot_types_reflect_Constant;
};

// Vtype
struct _jc_polyglot_types_reflect_Constant$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_Constant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Constant$sub_refs {
	struct _jc_java_lang_Object$object	*value;
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_Constant$refs {
    _jc_polyglot_types_reflect_Constant$sub_refs	polyglot_types_reflect_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Constant$sub_nonrefs {
	jint	tag;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_Constant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_Constant$sub_nonrefs	polyglot_types_reflect_Constant;
};

// Object instance structure
struct _jc_polyglot_types_reflect_Constant$object {
	_jc_polyglot_types_reflect_Constant$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_Constant$vtype	*vtype;
	_jc_polyglot_types_reflect_Constant$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_Constant$vtype _jc_polyglot_types_reflect_Constant$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_Constant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_Constant$class_object;

#endif	/* _JC_polyglot_types_reflect_Constant_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/reflect/Constant.h <==
// class polyglot.types.reflect.Constant

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 209b8df6d16abcfb polyglot_types_reflect_Constant

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_reflect_Constant_H_
#define _JC_polyglot_types_reflect_Constant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_Constant$sub_refs	_jc_polyglot_types_reflect_Constant$sub_refs;
typedef struct _jc_polyglot_types_reflect_Constant$sub_nonrefs	_jc_polyglot_types_reflect_Constant$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_Constant$refs	_jc_polyglot_types_reflect_Constant$refs;
typedef struct _jc_polyglot_types_reflect_Constant$nonrefs	_jc_polyglot_types_reflect_Constant$nonrefs;
typedef struct _jc_polyglot_types_reflect_Constant$object	_jc_polyglot_types_reflect_Constant$object;

typedef struct _jc_polyglot_types_reflect_Constant$fields_struct	_jc_polyglot_types_reflect_Constant$fields_struct;
typedef const struct _jc_polyglot_types_reflect_Constant$vmethods	_jc_polyglot_types_reflect_Constant$vmethods;
typedef const struct _jc_polyglot_types_reflect_Constant$vtable	_jc_polyglot_types_reflect_Constant$vtable;
typedef const struct _jc_polyglot_types_reflect_Constant$vtype	_jc_polyglot_types_reflect_Constant$vtype;

// Class fields structure
struct _jc_polyglot_types_reflect_Constant$fields_struct {
	jbyte	CLASS;
	jbyte	DOUBLE;
	jbyte	FIELD__5fREF;
	jbyte	FLOAT;
	jbyte	INTEGER;
	jbyte	INTERFACE__5fMETHOD__5fREF;
	jbyte	LONG;
	jbyte	METHOD__5fREF;
	jbyte	NAME__5fAND__5fTYPE;
	jbyte	STRING;
	jbyte	UTF8;
};
extern _jc_polyglot_types_reflect_Constant$fields_struct _jc_polyglot_types_reflect_Constant$class_fields;

// Constructors
extern void _jc_polyglot_types_reflect_Constant$method$_init$964b4a8e45252143(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_types_reflect_Constant$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_types_reflect_Constant$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_types_reflect_Constant$method$tag$c2c248fecb47553d(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_polyglot_types_reflect_Constant$method$value$b004c9f911e85e83(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_reflect_Constant$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_types_reflect_Constant$method_info$hashCode$53152098849316df;
extern _jc_method _jc_polyglot_types_reflect_Constant$method_info$tag$c2c248fecb47553d;
extern _jc_method _jc_polyglot_types_reflect_Constant$method_info$value$b004c9f911e85e83;

// Virtual methods structure
struct _jc_polyglot_types_reflect_Constant$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *) _JC_JCNI_ATTR;
	jint	(*tag$c2c248fecb47553d)(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*value$b004c9f911e85e83)(_jc_env *, struct _jc_polyglot_types_reflect_Constant$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_types_reflect_Constant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_Constant$vmethods	polyglot_types_reflect_Constant;
};

// Vtype
struct _jc_polyglot_types_reflect_Constant$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_Constant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Constant$sub_refs {
	struct _jc_java_lang_Object$object	*value;
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_Constant$refs {
    _jc_polyglot_types_reflect_Constant$sub_refs	polyglot_types_reflect_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_Constant$sub_nonrefs {
	jint	tag;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_Constant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_Constant$sub_nonrefs	polyglot_types_reflect_Constant;
};

// Object instance structure
struct _jc_polyglot_types_reflect_Constant$object {
	_jc_polyglot_types_reflect_Constant$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_Constant$vtype	*vtype;
	_jc_polyglot_types_reflect_Constant$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_Constant$vtype _jc_polyglot_types_reflect_Constant$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_Constant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_Constant$class_object;

#endif	/* _JC_polyglot_types_reflect_Constant_H_ */
